@@ -49,6 +49,26 @@ if (as.numeric(version$minor) < 3) {
 	setGeneric("transform", function(`_data`, ...)
 		standardGeneric("transform"))
 }
+
+bbox.default <- function(obj) {
+	is_points <- function(obj) {
+	    is <- FALSE
+	    if(is.array(obj))
+		if(length(dim(obj))==2)
+			if(dim(obj)[2]>=2) is <- TRUE
+	    is
+	}
+	if(!is_points(obj))stop('object not a >= 2-column array')
+	xr <- range(obj[,1],na.rm=TRUE)
+	yr <- range(obj[,2],na.rm=TRUE)
+	res <- rbind(x=xr, y=yr)
+	colnames(res) <- c("min","max")
+	res
+}
+
+
+setMethod("bbox", "ANY", bbox.default)
+
 setMethod("bbox", "Spatial", function(obj) obj@bbox)
 
 setMethod("dimensions", "Spatial", function(obj) nrow(bbox(obj)))
