@@ -60,7 +60,7 @@ points.SpatialPoints = function(x, y = NULL, ...) points(coordinates(x), ...)
 
 setMethod("coordinates", "SpatialPoints", function(obj) obj@coords)
 
-as.data.frame.SpatialPoints = function(x, row.names, optional) data.frame(x@coords)
+as.data.frame.SpatialPoints = function(x, row.names, optional, ...) data.frame(x@coords)
 
 setAs("SpatialPoints", "data.frame", function(from) as.data.frame(from))
 
